@@ -74,7 +74,7 @@ class KwargsWebSocketApp(WebsocketConsumer):
         self.send(text_data=self.scope["url_route"]["kwargs"]["message"])
 
 
-@pytest.mark.django_db
+@pytest.mark.django_db(transaction=True)
 @pytest.mark.asyncio
 async def test_websocket_communicator():
     """
@@ -101,7 +101,7 @@ async def test_websocket_communicator():
     await communicator.disconnect()
 
 
-@pytest.mark.django_db
+@pytest.mark.django_db(transaction=True)
 @pytest.mark.asyncio
 async def test_websocket_incorrect_read_json():
     """
@@ -120,7 +120,7 @@ async def test_websocket_incorrect_read_json():
     )
 
 
-@pytest.mark.django_db
+@pytest.mark.django_db(transaction=True)
 @pytest.mark.asyncio
 async def test_websocket_application():
     """
@@ -138,11 +138,12 @@ async def test_websocket_application():
     await communicator.disconnect()
 
 
-@pytest.mark.django_db
+@pytest.mark.django_db(transaction=True)
 @pytest.mark.asyncio
 async def test_timeout_disconnect():
     """
-    Tests that disconnect() still works after a timeout.
+    Tests that communicator.disconnect() raises after a timeout. (Application
+    is finished.)
     """
     communicator = WebsocketCommunicator(ErrorWebsocketApp(), "/testws/")
     # Test connection
@@ -153,8 +154,9 @@ async def test_timeout_disconnect():
     await communicator.send_to(text_data="hello")
     with pytest.raises(asyncio.TimeoutError):
         await communicator.receive_from()
-    # Close out
-    await communicator.disconnect()
+
+    with pytest.raises(asyncio.exceptions.CancelledError):
+        await communicator.disconnect()
 
 
 class ConnectionScopeValidator(WebsocketConsumer):
@@ -183,7 +185,7 @@ paths = [
 ]
 
 
-@pytest.mark.django_db
+@pytest.mark.django_db(transaction=True)
 @pytest.mark.asyncio
 @pytest.mark.parametrize("path", paths)
 async def test_connection_scope(path):
